@@ -74,7 +74,7 @@ class Language {
 		if (isset($GLOBALS['translations'])) {
 			return;
 		}
-		$lang = (empty($lang) || $lang == "C") ? LANG : $lang; // default language fix
+		$lang = (empty($lang) || substr($lang, 0, 1) == '.' || $lang == "C") ? LANG : $lang; // default language fix
 
 		if ($this->is_language($lang)) {
 			$this->lang = $lang;
@@ -184,16 +184,17 @@ class Language {
 	}
 
 	public function getTranslations() {
-		$memid = @shm_attach(0x950412DE, 16 * 1024 * 1024, 0666);
+		$memid = @shm_attach(0x950412DE, 16 * 1024 * 1024, 0644);
 		if (@shm_has_var($memid, 0)) {
 			$cache_table = @shm_get_var($memid, 0);
-			if (empty($cache_table)) {
+			$selected_lang = $this->getSelected();
+			if (empty($cache_table) || empty($cache_table[$selected_lang])) {
 				@shm_remove_var($memid, 0);
 				@shm_detach($memid);
 
 				return ['grommunio_web' => []];
 			}
-			$translation_id = $cache_table[$this->getSelected()];
+			$translation_id = $cache_table[$selected_lang];
 			if (empty($translation_id)) {
 				@shm_detach($memid);
 
