@@ -178,9 +178,13 @@ class MAPISession {
 			$user = $this->getUser($store_props[PR_USER_ENTRYID]);
 
 			// receive userdata
-			$user_props = [PR_DISPLAY_NAME, PR_SMTP_ADDRESS, PR_EMAIL_ADDRESS, PR_SEARCH_KEY, PR_EMS_AB_THUMBNAIL_PHOTO,
-				PR_TITLE, PR_COMPANY_NAME, PR_DEPARTMENT_NAME, PR_OFFICE_LOCATION, PR_HOME_ADDRESS_STREET, PR_MOBILE_TELEPHONE_NUMBER,
-				PR_PRIMARY_TELEPHONE_NUMBER, PR_BUSINESS_TELEPHONE_NUMBER, ];
+			$user_props = [ PR_ASSISTANT, PR_ASSISTANT_TELEPHONE_NUMBER, PR_BUSINESS2_TELEPHONE_NUMBER, PR_BUSINESS_TELEPHONE_NUMBER,
+				PR_COMPANY_NAME, PR_COUNTRY, PR_DEPARTMENT_NAME, PR_DISPLAY_NAME,
+				PR_EMAIL_ADDRESS, PR_EMS_AB_THUMBNAIL_PHOTO, PR_GIVEN_NAME, PR_HOME2_TELEPHONE_NUMBER,
+				PR_STREET_ADDRESS, PR_HOME_TELEPHONE_NUMBER, PR_INITIALS, PR_LOCALITY,
+				PR_MOBILE_TELEPHONE_NUMBER, PR_OFFICE_LOCATION, PR_PAGER_TELEPHONE_NUMBER, PR_POSTAL_CODE,
+				PR_PRIMARY_FAX_NUMBER, PR_PRIMARY_TELEPHONE_NUMBER, PR_SEARCH_KEY, PR_SMTP_ADDRESS,
+				PR_STATE_OR_PROVINCE, PR_SURNAME, PR_TITLE ];
 
 			$user_props = mapi_getprops($user, $user_props);
 
@@ -195,7 +199,7 @@ class MAPISession {
 				$this->session_info["given_name"] = isset($user_props[PR_GIVEN_NAME]) ? $user_props[PR_GIVEN_NAME] : '';
 				$this->session_info["initials"] = isset($user_props[PR_INITIALS]) ? $user_props[PR_INITIALS] : '';
 				$this->session_info["surname"] = isset($user_props[PR_SURNAME]) ? $user_props[PR_SURNAME] : '';
-				$this->session_info["street_address"] = isset($user_props[PR_HOME_ADDRESS_STREET]) ? $user_props[PR_HOME_ADDRESS_STREET] : '';
+				$this->session_info["street_address"] = isset($user_props[PR_STREET_ADDRESS]) ? $user_props[PR_STREET_ADDRESS] : '';
 				$this->session_info["locality"] = isset($user_props[PR_LOCALITY]) ? $user_props[PR_LOCALITY] : '';
 				$this->session_info["state_or_province"] = isset($user_props[PR_STATE_OR_PROVINCE]) ? $user_props[PR_STATE_OR_PROVINCE] : '';
 				$this->session_info["postal_code"] = isset($user_props[PR_POSTAL_CODE]) ? $user_props[PR_POSTAL_CODE] : '';
@@ -332,7 +336,6 @@ class MAPISession {
 	 */
 	public function getUserName() {
 		$encryptionStore = EncryptionStore::getInstance();
-
 		return $encryptionStore->get('username') ? $encryptionStore->get('username') : '';
 	}
 
@@ -343,7 +346,6 @@ class MAPISession {
 	 */
 	public function getFullName() {
 		$this->retrieveUserData();
-
 		return array_key_exists("fullname", $this->session_info) ? $this->session_info["fullname"] : false;
 	}
 
@@ -354,7 +356,6 @@ class MAPISession {
 	 */
 	public function getSMTPAddress() {
 		$this->retrieveUserData();
-
 		return array_key_exists("smtpaddress", $this->session_info) ? $this->session_info["smtpaddress"] : false;
 	}
 
@@ -365,7 +366,6 @@ class MAPISession {
 	 */
 	public function getEmailAddress() {
 		$this->retrieveUserData();
-
 		return array_key_exists("emailaddress", $this->session_info) ? $this->session_info["emailaddress"] : false;
 	}
 
@@ -376,7 +376,6 @@ class MAPISession {
 	 */
 	public function getUserImage() {
 		$this->retrieveUserData();
-
 		return array_key_exists("userimage", $this->session_info) ? $this->session_info["userimage"] : false;
 	}
 
@@ -387,116 +386,113 @@ class MAPISession {
 	}
 
 	public function getGivenName() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("given_name", $this->session_info) ? $this->session_info["given_name"] : false;
 	}
 
 	public function getInitials() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("initials", $this->session_info) ? $this->session_info["initials"] : false;
 	}
 
 	public function getSurname() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("surname", $this->session_info) ? $this->session_info["surname"] : false;
 	}
 
 	public function getStreetAddress() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("street_address", $this->session_info) ? $this->session_info["street_address"] : false;
 	}
 
 	public function getLocality() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("locality", $this->session_info) ? $this->session_info["locality"] : false;
 	}
 
 	public function getStateOrProvince() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("state_or_province", $this->session_info) ? $this->session_info["state_or_province"] : false;
 	}
 
 	public function getPostalCode() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("postal_code", $this->session_info) ? $this->session_info["postal_code"] : false;
 	}
 
 	public function getCountry() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("country", $this->session_info) ? $this->session_info["country"] : false;
 	}
 
 	public function getTitle() {
 		$this->retrieveUserData();
-
 		return array_key_exists("title", $this->session_info) ? $this->session_info["title"] : false;
 	}
 
 	public function getCompanyName() {
 		$this->retrieveUserData();
-
 		return array_key_exists("company_name", $this->session_info) ? $this->session_info["company_name"] : false;
 	}
 
 	public function getDepartmentName() {
 		$this->retrieveUserData();
-
 		return array_key_exists("department_name", $this->session_info) ? $this->session_info["department_name"] : false;
 	}
 
 	public function getOfficeLocation() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("office_location", $this->session_info) ? $this->session_info["office_location"] : false;
 	}
 
 	public function getAssistant() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("assistant", $this->session_info) ? $this->session_info["assistant"] : false;
 	}
 
 	public function getAssistantTelephoneNumber() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("assistant_telephone_number", $this->session_info) ? $this->session_info["assistant_telephone_number"] : false;
 	}
 
 	public function getOfficeTelephoneNumber() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("office_telephone_number", $this->session_info) ? $this->session_info["office_telephone_number"] : false;
 	}
 
 	public function getBusinessTelephoneNumber() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("business_telephone_number", $this->session_info) ? $this->session_info["business_telephone_number"] : false;
 	}
 
 	public function getBusiness2TelephoneNumber() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("business2_telephone_number", $this->session_info) ? $this->session_info["business2_telephone_number"] : false;
 	}
 
 	public function getPrimaryFaxNumber() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("primary_fax_number", $this->session_info) ? $this->session_info["primary_fax_number"] : false;
 	}
 
 	public function getHomeTelephoneNumber() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("home_telephone_number", $this->session_info) ? $this->session_info["home_telephone_number"] : false;
 	}
 
 	public function getHome2TelephoneNumber() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("home2_telephone_number", $this->session_info) ? $this->session_info["home2_telephone_number"] : false;
 	}
 
 	public function getMobileTelephoneNumber() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("mobile_telephone_number", $this->session_info) ? $this->session_info["mobile_telephone_number"] : false;
 	}
 
 	public function getPagerTelephoneNumber() {
-		// TODO
-		return "";
+		$this->retrieveUserData();
+		return array_key_exists("pager_telephone_number", $this->session_info) ? $this->session_info["pager_telephone_number"] : false;
 	}
 
 	/**
@@ -506,15 +502,24 @@ class MAPISession {
 	 */
 	public function getDisabledFeatures() {
 		$userProps = mapi_getprops($this->getUser(), [PR_EC_DISABLED_FEATURES]);
-
 		return isset($userProps[PR_EC_DISABLED_FEATURES]) ? $userProps[PR_EC_DISABLED_FEATURES] : [];
 	}
 
+	/**
+	 * Checks whether the user is enabled for grommunio-web.
+	 *
+	 * @return bool
+	 */
+	public function isGwebEnabled() {
+		$store_props = mapi_getprops($this->getDefaultMessageStore(), [PR_EC_ENABLED_FEATURES_L]);
+		return $store_props[PR_EC_ENABLED_FEATURES_L] & UP_WEB;
+	}
+
 	/**
 	 * @return bool true if webapp is disabled feature else return false
 	 */
 	public function isWebappDisableAsFeature() {
-		return array_search('webapp', $this->getDisabledFeatures()) !== false;
+		return !$this->isGwebEnabled() || array_search('webapp', $this->getDisabledFeatures()) !== false;
 	}
 
 	/**
@@ -592,7 +597,6 @@ class MAPISession {
 	 */
 	public function getSearchKey() {
 		$this->retrieveUserData();
-
 		return $this->session_info["searchkey"] ?? '';
 	}
 
@@ -849,11 +853,8 @@ class MAPISession {
 					$user_entryid = mapi_msgstore_createentryid($this->getDefaultMessageStore(), $username);
 
 					$sharedStore = $this->openMessageStore($user_entryid, $username);
-					if ($sharedStore !== false && $sharedStore !== ecLoginPerm &&
-						$sharedStore !== MAPI_E_CALL_FAILED && $sharedStore !== MAPI_E_NOT_FOUND) {
-						array_push($otherUsersStores, $sharedStore);
-					}
-					else {
+					if ($sharedStore === false && $sharedStore === ecLoginPerm &&
+						$sharedStore === MAPI_E_CALL_FAILED && $sharedStore === MAPI_E_NOT_FOUND) {
 						$storeOk = false;
 					}
 
@@ -889,7 +890,7 @@ class MAPISession {
 		}
 
 		foreach ($this->userstores as $entryid) {
-			array_push($otherUsersStores, $this->stores[$entryid]);
+			$otherUsersStores[$entryid] = $this->stores[$entryid];
 		}
 
 		return $otherUsersStores;
@@ -1060,14 +1061,17 @@ class MAPISession {
 					$this->getOtherUserStore();
 				}
 
+				$sharedSetting = $GLOBALS["settings"]->get("zarafa/v1/contexts/hierarchy/shared_stores", []);
 				// Find available contact folders from all user stores, one by one.
 				foreach ($this->userstores as $username => $storeEntryID) {
 					$userContactFolders = [];
+					$sharedUserSetting = [];
 					$openedUserStore = $this->openMessageStore($storeEntryID, $username);
 
 					// Get settings of respective shared folder of given user
-					$sharedSetting = $GLOBALS["settings"]->get("zarafa/v1/contexts/hierarchy/shared_stores", null);
-					$sharedUserSetting = $sharedSetting[strtolower(hex2bin($username))];
+					if (array_key_exists(strtolower(bin2hex($username)), $sharedSetting)) {
+						$sharedUserSetting = $sharedSetting[strtolower(bin2hex($username))];
+					}
 
 					// Only add opened shared folders into addressbook contacts provider.
 					// If entire inbox is opened then add each and every contact folders of that particular user.
@@ -1124,7 +1128,7 @@ class MAPISession {
 
 			// Create the lists of store entryids, folder entryids and folder names to be added
 			// to the profile section
-			for ($i = 0,$len = count($contactFolders); $i < $len; ++$i) {
+			for ($i = 0, $len = count($contactFolders); $i < $len; ++$i) {
 				$contact_store_entryids[] = $contactFolders[$i][PR_STORE_ENTRYID];
 				$contact_folder_entryids[] = $contactFolders[$i][PR_ENTRYID];
 				$contact_folder_names[] = $contactFolders[$i][PR_DISPLAY_NAME];
@@ -1149,31 +1153,23 @@ class MAPISession {
 	 */
 	public function getContactFoldersForABContactProvider($store) {
 		$storeProps = mapi_getprops($store, [PR_ENTRYID, PR_MDB_PROVIDER, PR_IPM_SUBTREE_ENTRYID, PR_IPM_PUBLIC_FOLDERS_ENTRYID]);
-
-		// For the public store we need to use the PR_IPM_PUBLIC_FOLDERS_ENTRYID instead of the
-		// PR_IPM_SUBTREE_ENTRYID that can be used on your own and delegate stores.
-		if ($storeProps[PR_MDB_PROVIDER] == ZARAFA_STORE_PUBLIC_GUID) {
-			$subtreeEntryid = $storeProps[PR_IPM_PUBLIC_FOLDERS_ENTRYID];
-		}
-		else {
-			$subtreeEntryid = $storeProps[PR_IPM_SUBTREE_ENTRYID];
-		}
-
 		$contactFolders = [];
 
 		try {
 			// Only searches one level deep, otherwise deleted contact folders will also be included.
-			$contactFolders = $this->getContactFolders($store, $subtreeEntryid, false);
+			$contactFolders = $this->getContactFolders($store, $storeProps[PR_IPM_SUBTREE_ENTRYID], $storeProps[PR_MDB_PROVIDER] === ZARAFA_STORE_PUBLIC_GUID ? true : false);
 		}
 		catch (Exception $e) {
 			return $contactFolders;
 		}
 
 		// Need to search all the contact-subfolders within first level contact folders.
-		$firstLevelHierarchyNodes = $contactFolders;
-		foreach ($firstLevelHierarchyNodes as $key => $firstLevelNode) {
-			// To search for multiple levels CONVENIENT_DEPTH needs to be passed as well.
-			$contactFolders = array_merge($contactFolders, $this->getContactFolders($store, $firstLevelNode[PR_ENTRYID], true));
+		if ($storeProps[PR_MDB_PROVIDER] != ZARAFA_STORE_PUBLIC_GUID) {
+			$firstLevelHierarchyNodes = $contactFolders;
+			foreach ($firstLevelHierarchyNodes as $firstLevelNode) {
+				// To search for multiple levels CONVENIENT_DEPTH needs to be passed as well.
+				$contactFolders = array_merge($contactFolders, $this->getContactFolders($store, $firstLevelNode[PR_ENTRYID], true));
+			}
 		}
 
 		return $contactFolders;
@@ -1220,7 +1216,7 @@ class MAPISession {
 		$contactFolderTable = mapi_folder_gethierarchytable($hierarchyFolder, $depthFlag);
 		mapi_table_restrict($contactFolderTable, $restriction, TBL_BATCH);
 
-		return mapi_table_queryallrows($contactFolderTable, [PR_STORE_ENTRYID, PR_ENTRYID, PR_DISPLAY_NAME]);
+		return mapi_table_queryallrows($contactFolderTable, [PR_STORE_ENTRYID, PR_ENTRYID, PR_DISPLAY_NAME, PR_PARENT_ENTRYID, PR_DEPTH]);
 	}
 
 	/**
