@@ -154,7 +154,7 @@ class ContactItemModule extends ItemModule {
 					}
 					else {
 						$parts = [];
-						$parts['distlist_guid'] = DL_GUID;
+						$parts['distlist_guid'] = WAB_GUID;
 						$parts['distlist_type'] = $item['distlist_type'];
 						$parts['entryid'] = hex2bin($item['entryid']);
 						$member = pack('VA16CA*', 0, $parts['distlist_guid'], $parts['distlist_type'], $parts['entryid']);
@@ -527,6 +527,10 @@ class ContactItemModule extends ItemModule {
 			$data['entryid'] = $entryid;
 		}
 
+		if (isset($action['timezone_iana'])) {
+			$props['timezone_iana'] = $action['timezone_iana'];
+		}
+
 		$data['props'] = $props;
 
 		// Save appointment (saveAppointment takes care of creating/modifying exceptions to recurring
